| fitDatasets_lmer | R Documentation |
Methods to fit various mixed effects estimators to all generated datasets.
fitDatasets_lmer(datasets, control, label, postFit, datasetIndices = "all")
fitDatasets_lmer_bobyqa(datasets, postFit, datasetIndices = "all")
fitDatasets_lmer_Nelder_Mead(datasets, postFit, datasetIndices = "all")
fitDatasets_rlmer(
datasets,
method,
tuningParameter,
label,
postFit,
datasetIndices = "all",
...,
init
)
fitDatasets_rlmer_DAStau(datasets, postFit, datasetIndices = "all")
fitDatasets_rlmer_DAStau_lmerNoFit(datasets, postFit, datasetIndices = "all")
fitDatasets_rlmer_DASvar(datasets, postFit, datasetIndices = "all")
fitDatasets_rlmer_DAStau_noAdj(datasets, postFit, datasetIndices = "all")
fitDatasets_rlmer_DAStau_k_0_5(datasets, postFit, datasetIndices = "all")
fitDatasets_rlmer_DAStau_k_0_5_noAdj(datasets, postFit, datasetIndices = "all")
fitDatasets_rlmer_DAStau_k_2(datasets, postFit, datasetIndices = "all")
fitDatasets_rlmer_DAStau_k_2_noAdj(datasets, postFit, datasetIndices = "all")
fitDatasets_rlmer_DAStau_k_5(datasets, postFit, datasetIndices = "all")
fitDatasets_rlmer_DAStau_k_5_noAdj(datasets, postFit, datasetIndices = "all")
fitDatasets_rlmer_DAStau_bisq(datasets, postFit, datasetIndices = "all")
fitDatasets_rlmer_DAStau_sizeOBR(datasets, postFit, datasetIndices = "all")
fitDatasets_rlmer_ransac(
datasets,
postFit,
datasetIndices = "all",
K = 50L,
sub_frac = 0.5
)
fitDatasets_rlmer_ransac_bisq(
datasets,
postFit,
datasetIndices = "all",
K = 50L,
sub_frac = 0.5
)
fitDatasets_heavyLme(datasets, postFit, datasetIndices = "all")
fitDatasets_lqmm(datasets, postFit, datasetIndices = "all")
fitDatasets_rlme(datasets, postFit, datasetIndices = "all")
fitDatasets_varComprob(
datasets,
control,
label,
postFit,
datasetIndices = "all"
)
fitDatasets_varComprob_compositeTau(datasets, postFit, datasetIndices = "all")
fitDatasets_varComprob_compositeTau_OGK(
datasets,
postFit,
datasetIndices = "all"
)
fitDatasets_varComprob_compositeTau_2SGS(
datasets,
postFit,
datasetIndices = "all"
)
fitDatasets_varComprob_compositeS(datasets, postFit, datasetIndices = "all")
fitDatasets_varComprob_compositeS_OGK(
datasets,
postFit,
datasetIndices = "all"
)
fitDatasets_varComprob_compositeS_2SGS(
datasets,
postFit,
datasetIndices = "all"
)
fitDatasets_varComprob_S(datasets, postFit, datasetIndices = "all")
fitDatasets_varComprob_S_OGK(datasets, postFit, datasetIndices = "all")
fitDatasets_varComprob_S_2SGS(datasets, postFit, datasetIndices = "all")
datasets |
Datasets list to be used to generate datasets. |
control |
a list (of correct class for the respective fitting function) containing control parameters to be passed through. |
label |
a string used to identify which fits have been created by which function. |
postFit |
a function, taking one argument, the resulting fit. This makes it easy to add an additional step after fitting. |
datasetIndices |
optional vector of dataset indices to fit, useful to try only a few datasets instead of all of them. |
method |
argument passed on to |
tuningParameter |
argument passed on to
|
... |
argument passed on to |
init |
optional argument passed on to |
K |
number of random subsamples used by the RANSAC initial
estimator ( |
sub_frac |
fraction of the data per RANSAC subsample. Only used by
|
Existing fitting functions are:
fitDatasets_lmer: Fits datasets using lmer
using its default options.
fitDatasets_lmer_bobyqa: Fits datasets using lmer using
the bobyqa optimizer.
fitDatasets_lmer_Nelder_Mead: Fits datasets using
lmer using the Nelder Mead optimizer.
fitDatasets_rlmer: Fits datasets using rlmer
using a custom configuration. The argument 'tuningParameter' is passed to
extractTuningParameter, details are documented there.
fitDatasets_rlmer_DAStau: Fits datasets using
rlmer using method DAStau and smoothPsi for
the rho functions. The tuning parameters are k = 1.345 for rho.e.
For rho.sigma.e, the Proposal 2 variant is used using k = 2.28.
The choices for rho.b and rho.sigma.b depend on whether the
model uses a diagonal or a block diagonal matrix for Lambda. In the former
case, the same psi functions and tuning parameters are use as for
rho.e and rho.sigma.b. In the block diagonal case,
rho.b and rho.sigma.b both use smoothPsi using
a tuning parameter k = 5.14 (assuming blocks of dimension 2).
fitDatasets_rlmer_DAStau_lmerNoFit: Fits datasets using
rlmer using the same configuration as
fitDatasets_rlmer_DAStau except for that it is using
lmerNoFit as initial estimator.
fitDatasets_rlmer_DASvar: Fits datasets using
rlmer using method DASvar. The same rho functions and tuning
parameters are used as for fitDatasets_rlmer_DAStau.
fitDatasets_rlmer_DAStau_noAdj: Fits datasets using
rlmer using method DAStau. The same rho functions and tuning
parameters are used as for fitDatasets_rlmer_DAStau, except for
rho.sigma.e (and rho.sigma.b in the diagonal case) for which
the Proposal 2 variant of smoothPsi using k = 1.345 is used.
fitDatasets_rlmer_DAStau_k_0_5: Fits datasets using
rlmer using method DAStau. Use smoothPsi
psi-function with tuning parameter k = 0.5 for rho.e and
k = 1.47 for rho.sigma.e, the latter adjusted to reach the
same asymptotic efficiency. In the diagonal case, the same are used for
rho.b and rho.sigma.b as well. In the block-diagonal case,
the tuning parameter k = 2.17 is used for rho.b and
rho.sigma.b. The tuning parameter is chosen to reach about the same
asymptotic efficiency for theta as for the fixed effects.
fitDatasets_rlmer_DAStau_k_0_5_noAdj: Fits datasets using
rlmer using method DAStau. Use smoothPsi
psi-function with tuning parameter k = 0.5 for rho.e and
rho.sigma.e. In the diagonal case, the same are used for
rho.b and rho.sigma.b as well. In the block-diagonal case,
the tuning parameter k = 2.17 is used for rho.b and
rho.sigma.b. The tuning parameter is chosen to reach about the same
asymptotic efficiency for theta as for the fixed effects.
fitDatasets_rlmer_DAStau_k_2: Fits datasets using
rlmer using method DAStau. Use smoothPsi
psi-function with tuning parameter k = 2 for rho.e and
k = 2.9 rho.sigma.e, the latter adjusted to reach the same
asymptotic efficiency. In the diagonal case, the same are used for
rho.b and rho.sigma.b as well. In the block-diagonal case,
the tuning parameter k = 8.44 is used for rho.b and
rho.sigma.b. The tuning parameter is chosen to reach about the same
asymptotic efficiency for theta as for the fixed effects.
fitDatasets_rlmer_DAStau_k_2_noAdj: Fits datasets using
rlmer using method DAStau. Use smoothPsi
psi-function with tuning parameter k = 2 for rho.e and
rho.sigma.e. In the diagonal case, the same are used for
rho.b and rho.sigma.b as well. In the block-diagonal case,
the tuning parameter k = 8.44 is used for rho.b and
rho.sigma.b. The tuning parameter is chosen to reach about the same
asymptotic efficiency for theta as for the fixed effects.
fitDatasets_rlmer_DAStau_k_5: Fits datasets using
rlmer using method DAStau. Use smoothPsi
psi-function with tuning parameter k = 5 for rho.e and
k = 5.03 rho.sigma.e, the latter adjusted to reach the same
asymptotic efficiency. In the diagonal case, the same are used for
rho.b and rho.sigma.b as well. In the block-diagonal case,
the tuning parameter k = 34.21 is used for rho.b and
rho.sigma.b. The tuning parameter is chosen to reach about the same
asymptotic efficiency for theta as for the fixed effects.
fitDatasets_rlmer_DAStau_k_5_noAdj: Fits datasets using
rlmer using method DAStau. Use smoothPsi
psi-function with tuning parameter k = 5 for rho.e and
rho.sigma.e. In the diagonal case, the same are used for
rho.b and rho.sigma.b as well. In the block-diagonal case,
the tuning parameter k = 34.21 is used for rho.b and
rho.sigma.b. The tuning parameter is chosen to reach about the same
asymptotic efficiency for theta as for the fixed effects.
fitDatasets_rlmer_DAStau_bisq: Fits datasets using
rlmer with method DAStau, replacing rho.e with
the redescending bisquare psi (bisquarePsi, c = 4.685).
The other rho-functions use the same smoothed Huber psi and tuning
parameters as fitDatasets_rlmer_DAStau.
fitDatasets_rlmer_DAStau_sizeOBR: Fits datasets using
rlmer with method DAStau and size_obr = TRUE,
which replaces the finite-difference size weight in the
block-diagonal V_b score equation with the Hampel-OBR form. The
same rho-functions and tuning parameters are used as for
fitDatasets_rlmer_DAStau. For diagonal V_b the
size_obr argument is silently ignored.
fitDatasets_rlmer_ransac: Fits datasets using
rlmer with method DAStau and a RANSAC-derived initial
estimator (ransac_lme4). The number of random
subsamples is K = 50 with subsample fraction
sub_frac = 0.5. Same rho-functions and tuning parameters
as fitDatasets_rlmer_DAStau.
fitDatasets_rlmer_ransac_bisq: Combines
fitDatasets_rlmer_ransac (RANSAC init) with
fitDatasets_rlmer_DAStau_bisq (bisquarePsi
for rho.e). Designed to give redescending psi a starting
value safely away from phony local minima.
fitDatasets_heavyLme: Fits datasets using
heavyLme from package heavy. Additional
required arguments are: lmeFormula, heavyLmeRandom and
heavyLmeGroups. They are passed to the formula,
random and groups arguments of heavyLme.
fitDatasets_lqmm: Fits datasets using
lqmm from package lqmm. Additional required
arguments are: lmeFormula, lqmmRandom, lqmmGroup and
lqmmCovariance. They are passed to the formula,
random, groups and covariance arguments of
lqmm. lqmmCovariance is optional, if omitted pdDiag
is used.
fitDatasets_rlme: Fits datasets using
rlme from package rlme.
fitDatasets_varComprob: Prototype method to fit datasets
using varComprob from package
robustvarComp. Additional required items in datasets are:
lmeFormula, groups, varcov and lower. They are
passed to the fixed, groups, varcov and lower
arguments of varComprob. The running of this method produces many
warnings of the form "passing a char vector to .Fortran is not portable"
which are suppressed.
fitDatasets_varComprob_compositeTau: Fits datasets with the
composite Tau method using varComprob from
package robustvarComp. See fitDatasets_varComprob for
additional details.
fitDatasets_varComprob_compositeTau_OGK: Similar to
fitDatasets_varComprob_compositeTau but using covOGK as initial
covariance matrix estimator.
fitDatasets_varComprob_compositeTau_2SGS: Similar to
fitDatasets_varComprob_compositeTau but using 2SGS as initial covariance
matrix estimator.
fitDatasets_varComprob_compositeS: Similar to
fitDatasets_varComprob_compositeTau but using method composite S.
fitDatasets_varComprob_compositeS_OGK: Similar to
fitDatasets_varComprob_compositeS but using covOGK as
initial covariance matrix estimator.
fitDatasets_varComprob_compositeS_2SGS: Similar to
fitDatasets_varComprob_compositeS but using 2SGS as initial
covariance matrix estimator.
fitDatasets_varComprob_S: Similar to
fitDatasets_varComprob_compositeTau but using method S and the
Rocke psi-function.
fitDatasets_varComprob_S_OGK: Similar to
fitDatasets_varComprob_S but using covOGK as initial
covariance matrix estimator.
fitDatasets_varComprob_S_2SGS: Similar to
fitDatasets_varComprob_S but using 2SGS as initial
covariance matrix estimator.
list of fitted models. See also lapplyDatasets which
is called internally.
Manuel Koller
set.seed(1)
oneWay <- generateAnovaDatasets(1, 1, 10, 4,
lmeFormula = y ~ 1,
heavyLmeRandom = ~ 1,
heavyLmeGroups = ~ Var2,
lqmmRandom = ~ 1,
lqmmGroup = "Var2",
groups = cbind(rep(1:4, each = 10), rep(1:10, 4)),
varcov = matrix(1, 4, 4),
lower = 0)
fitDatasets_lmer(oneWay)
## call rlmer with custom arguments
fitDatasets_rlmer_custom <- function(datasets) {
return(fitDatasets_rlmer(datasets,
method = "DASvar",
tuningParameter = c(1.345, 2.28, 1.345, 2.28, 5.14, 5.14),
label = "fitDatasets_rlmer_custom"))
}
fitDatasets_rlmer_custom(oneWay)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.