plot.rlmerMod: Plot Method for "rlmerMod" objects.
Description
Diagnostic plots for objects of class rlmerMod and lmerMod.
Usage
# S3 method for rlmerMod
plot(
x,
y = NULL,
which = 1:4,
title = c("Fitted Values vs. Residuals", "Normal Q-Q vs. Residuals",
"Normal Q-Q vs. Random Effects", "Scatterplot of Random Effects for Group \"%s\""),
multiply.weights = FALSE,
...
)
a list of plots of class ggplot that can be
used for further modification before plotting (using print).
Arguments
x
an object as created by rlmer or rlmer; or an object
as created by plot.rlmerMod
y
currently ignored.
which
integer number between 1 and 4 to specify which plot is
desired.
title
Titles for the different plots. The fourth item can be a format
string passed to sprintf to add the name of the current group.
multiply.weights
multiply the residuals / random effects with the
robustness weights when producing the Q-Q plots.
...
currently ignored.
ask
waits for user input before displaying each plot.
Details
The robustness weights for estimating the fixed and random effects are used
in the plots, e.g., the ones returned by getME(object, "w_e") and
getME(object, "w_b").