The “classical” \(\psi\)-function
cPsi can be used to get a non-robust, i.e.,
classical, fit. The psi slot equals the identity
function, and the rho slot equals quadratic
function. Accordingly, the robustness weights will always
be 1 when using cPsi.
The Huber \(\psi\)-function huberPsiRcpp
is identical to the one in the package robustbase.
The psi slot equals the identity function within
\(\pm k\) (where \(k\) is the tuning
parameter). Outside this interval it is equal to \(\pm
k\). The rho slot equals the quadratic
function within \(\pm k\) and a linear function
outside.
The smoothed Huber \(\psi\)-function is
very similar to the regular Huber
\(\psi\)-function. Instead of a sharp bend like
the Huber function, the smoothe Huber function bends
smoothly. The first tuning contant, k, can be compared to
the tuning constant of the original Huber function. The
second tuning constant, s, determines the smoothness of
the bend.