makeBisquarePsi: Bisquare (Tukey biweight) psi function

View source: R/redescendingPsi.R

makeBisquarePsiR Documentation

Bisquare (Tukey biweight) psi function

Description

Construct a redescending Tukey bisquare psi function.

Usage

makeBisquarePsi(c = 4.685)

Arguments

c

tuning cutoff. The default c = 4.685 gives about 95% asymptotic efficiency for the location problem.

Details

Returns a psi_func_rcpp object whose psi, rho, weight and derivative slots implement Tukey's bisquare (biweight) function

\psi(x) = x (1 - (x/c)^2)^2 \quad \text{for } |x| \le c,\quad 0 \text{ otherwise}

suitable for use as rho.e (or rho.b, rho.sigma.e, rho.sigma.b) in rlmer.

The Fisher consistency expectations (Erho, Epsi2, EDpsi) are computed by numerical integration against the standard normal.

Value

psi_func_rcpp object usable in rho.e, rho.b.

Examples

  pf <- bisquarePsi
  pf@psi(c(-6, -3, 0, 3, 6))

robustlmm documentation built on June 21, 2026, 5:12 p.m.